@@ -114,7 +114,7 @@ sub cPageFooter {
 	if (FAQ::OMatic::getParam($params, 'render') eq 'text') {
 		return "Generated by FAQ-O-Matic $FAQ::OMatic::VERSION,\n"
 			."available at "
-			."http://www.dartmouth.edu/cgi-bin/cgiwrap/jonh/faq.pl\n"
+			."http://faqomatic.sourceforge.net/\n"
 	} else {
 		my $page = '';
 		$page .= navigationBlock($params, $showLinks);
@@ -261,7 +261,7 @@ sub navigationBlock {
 
 	my $page = "\n<!--footer box at bottom of page with common links -->\n";
 	my $software = gettext("This is a") . " <a href=\""
-			."http://www.dartmouth.edu/cgi-bin/cgiwrap/jonh/faq.pl"
+			."http://faqomatic.sourceforge.net/"
 			."\">Faq-O-Matic</a> $FAQ::OMatic::VERSION.\n";
 	if ($useTable) {
 		my $tw = $FAQ::OMatic::Config::tableWidth || '';
