@@ -33,9 +33,10 @@ use CGI;
 use FAQ::OMatic::Item;
 use FAQ::OMatic;
 use FAQ::OMatic::Auth;
+use FAQ::OMatic::I18N;
 
 sub main {
-	my $cgi = $FAQ::OMatic::dispatch::cgi;
+	my $cgi = FAQ::OMatic::dispatch::cgi();
 	my $params = FAQ::OMatic::getParams($cgi);
 
 	FAQ::OMatic::mirrorsCantEdit($cgi, $params);
@@ -47,12 +48,12 @@ sub main {
 	my $movingItem = new FAQ::OMatic::Item($movingFilename);
 	if ($movingItem->isBroken()) {
 		FAQ::OMatic::gripe('error',
-			"The moving file ($movingFilename) is broken or missing.");
+			gettext("The moving file")." ($movingFilename) ".gettext("is broken or missing."));
 	}
 	my $newParentItem = new FAQ::OMatic::Item($newParentFilename);
 	if ($newParentItem->isBroken()) {
 		FAQ::OMatic::gripe('error',
-			"The newParent file ($newParentFilename) is broken or missing.");
+			gettext("The newParent file")." ($newParentFilename) ".gettext("is broken or missing."));
 	}
 
 	# load up the old parent
@@ -60,53 +61,52 @@ sub main {
 	my $oldParentItem = new FAQ::OMatic::Item($oldParentFilename);
 	if ($oldParentItem->isBroken()) {
 		FAQ::OMatic::gripe('error',
-			"The oldParent file ($oldParentFilename) is broken or missing.");
+			gettext("The oldParent file")." ($oldParentFilename) ".gettext("is broken or missing."));
 	}
 
 	# make sure the new parent isn't the old parent or
 	# the moving item itself
 	if ($newParentFilename eq $oldParentFilename) {
 		FAQ::OMatic::gripe('error',
-			"The new parent (".$newParentItem->getTitle()
-			.") is the same as the old parent.");
+			gettext("The new parent")." (".$newParentItem->getTitle()
+			.") ".gettext("is the same as the old parent."));
 	}
 	if ($newParentFilename eq $movingFilename) {
 		FAQ::OMatic::gripe('error',
-			"The new parent (".$newParentItem->getTitle()
-			.") is the same as the item you want to move.");
+			gettext("The new parent")." (".$newParentItem->getTitle()
+			.") ".gettext("is the same as the item you want to move."));
 	}
 	
 	# make sure the new parent isn't a child of movingItem
 	if ($newParentItem->hasParent($movingFilename)) {
 		FAQ::OMatic::gripe('error',
-			"The new parent (".$newParentItem->getTitle()
-			.") is a child of the item being moved ("
+			gettext("The new parent")." (".$newParentItem->getTitle()
+			.") ".gettext("is a child of the item being moved")." ("
 			.$movingItem->getTitle().").");
 	}
 
 	if ($movingItem->{'filename'} eq '1') {
-		FAQ::OMatic::gripe('error', "You can't move the top item.");
+		FAQ::OMatic::gripe('error', gettext("You can't move the top item."));
 	}
 
 	# check permissions on the parents to see that the move is legal
-	my ($rd1,$aq1) =
-		FAQ::OMatic::Auth::ensurePerm($oldParentItem, 'PermEditItem',
+	# we need to check more than a single permission, and want
+	# to return the error corresponding to the greater of the two.
+	my ($url1,$aq1) =
+		FAQ::OMatic::Auth::ensurePerm($oldParentItem, 'PermEditDirectory',
 		'submitMove', $cgi, 1);
-	my ($rd2,$aq2) =
-		FAQ::OMatic::Auth::ensurePerm($newParentItem, 'PermEditItem',
+	my ($url2,$aq2) =
+		FAQ::OMatic::Auth::ensurePerm($newParentItem, 'PermAddItem',
 		'submitMove', $cgi, 1);
 
 	# If both ends of the move are not authorized, demand authentication
 	# at the higher of the two levels
-	if ($rd1 and $rd2) {
-		print( ($aq1 > $aq2) ? $rd1 : $rd2 );
-		exit 0;
-	} elsif ($rd1) {
-		print $rd1;
-		exit 0;
-	} elsif ($rd2) {
-		print $rd2;
-		exit 0;
+	if ($url1 and $url2) {
+		FAQ::OMatic::redirect($cgi, ($aq1 > $aq2) ? $url1 : $url2 );
+	} elsif ($url1) {
+		FAQ::OMatic::redirect($cgi, $url1);
+	} elsif ($url2) {
+		FAQ::OMatic::redirect($cgi, $url2);
 	}
 
 	# don't remove an item from itself if it's a root (own parent)
@@ -124,16 +124,21 @@ sub main {
 		FAQ::OMatic::Auth::getInheritedProperty($oldParentItem, 'Moderator');
 	my $newModerator =
 		FAQ::OMatic::Auth::getInheritedProperty($newParentItem, 'Moderator');
-	$oldParentItem->notifyModerator($cgi, "moved a sub-item to "
+	$oldParentItem->notifyModerator($cgi, gettext("moved a sub-item to")." "
 			.$newParentItem->getTitle());
 	if ($newModerator ne $oldModerator) {
-		$newParentItem->notifyModerator($cgi, "moved a sub-item from "
+		$newParentItem->notifyModerator($cgi, gettext("moved a sub-item from")." "
 			.$oldParentItem->getTitle());
 	}
 
-	my $url = FAQ::OMatic::makeAref('faq', {'file'=>$newParentFilename}, 'url');
+	# If user clicked "trash this item," they probably don't want
+	# to go see it in the trash.
+	my $target = ($newParentFilename ne 'trash')
+		? $newParentFilename
+		: $oldParentFilename;
+	my $url = FAQ::OMatic::makeAref('faq', {'file'=>$target}, 'url');
 
-	print $cgi->redirect(FAQ::OMatic::urlBase($cgi).$url);
+	FAQ::OMatic::redirect($cgi, $url);
 }
 
 1;
